@@ -18,6 +18,11 @@ import matplotlib
 import datetime
 import multiprocessing as mp
 import pickle
+from scipy.io import wavfile
+import warnings
+import ooipy
+import pandas as pd
+import os
 
 
 class HydrophoneData(Trace):
@@ -38,26 +43,30 @@ class HydrophoneData(Trace):
         the data object is divided into N segments and for each
         segment a separate power spectral density estimate is computed and
         stored in psd_list. psd_list is computed by compute_psd_welch_mp
+    type : str
+        Either 'broadband' or 'low_frequency' specifies the type of hydrophone
+        that the date is from.
 
     """
 
     def __init__(self, data=np.array([]), header=None, node=''):
 
-        super(HydrophoneData, self).__init__(data, header)
-
-        self.stats.location = node
+        super().__init__(data, header)
+        self.stats.location = node_id(node)
 
         self.spectrogram = None
         self.psd = None
         self.psd_list = None
+        self.type = None
 
     # TODO: use correct frequency response for all hydrophones
-    def freq_dependent_sensitivity_correct(self, N, node, time):
+    def frequency_calibration(self, N):
         # TODO
         """
         Apply a frequency dependent sensitivity correction to the
         acoustic data based on the information from the calibration
         sheets.
+        TODO Add for all broadband hydrophones
         !!! Currently only implemented for Oregon Offshore Base Seafloor
         and Oregon Shelf Base Seafloor hydrophone. For all other
         hydrophones, an average sensitivity of -169dBV/1uPa is assumed
@@ -67,88 +76,39 @@ class HydrophoneData(Trace):
         ----------
         N : int
             length of the data segment
-        node : str
-            hydrophone node
-        time : datetime.datetime
-            time of acoustic data. The sensitivity correction varies
-            depending on the measurement time
 
         Returns
         -------
         output_array : np.array
             array with correction coefficient for every frequency
         """
+        # Load calibation file and get appropriate calibration info
+        filename = os.path.dirname(ooipy.__file__) + \
+            '/hydrophone/calibration_by_assetID.csv'
+        # Use deployment CSV to determine asset_ID
+        assetID = self.get_asset_ID()
 
-        f = np.linspace(0, 32000, N)
-        if node == '/LJ01C':  # Oregon Offshore Base Seafloor
-            if time >= datetime.datetime(2014, 8, 15, 0, 12, 0) and \
-                    time <= datetime.datetime(2015, 8, 2, 0, 0, 0) or \
-                    time >= datetime.datetime(2016, 7, 22, 22, 50, 0) and \
-                    time <= datetime.datetime(2017, 8, 10, 4, 0, 0):  # 1249
-                f_calib = [0, 26, 13500, 27100, 40600, 54100]
-                sens_calib = [168.49, 168.49, 169.3, 169.6, 172.6, 171.8]
-                sens_interpolated = interp1d(f_calib, sens_calib)
-            elif time >= datetime.datetime(2020, 9, 1, 0, 0, 0):  # 1249
-                f_calib = [0, 26, 10000, 20100, 30100, 40200, 50200]
-                sens_calib = [168.5, 168.5, 167.6, 169.45, 171.85,
-                              172.65, 171.7]
-                sens_interpolated = interp1d(f_calib, sens_calib)
-            elif time >= datetime.datetime(2018, 6, 25, 0, 0, 0) and \
-                    time <= datetime.datetime(2019, 6, 19, 4, 17, 0):  # 1248
-                f_calib = [0, 26, 10000, 20100, 30100, 40200, 50200]
-                sens_calib = [170.5, 170.5, 169.75, 172.85, 173.35,
-                              172.85, 172.25]
-                sens_interpolated = interp1d(f_calib, sens_calib)
-            elif time >= datetime.datetime(2015, 8, 3, 22, 45, 0) and \
-                    time <= datetime.datetime(2016, 7, 22, 22, 49, 59) or \
-                    time >= datetime.datetime(2017, 8, 10, 16, 0, 0) and \
-                    time <= datetime.datetime(2018, 6, 25, 0, 0, 0) or \
-                    time >= datetime.datetime(2019, 6, 23, 22, 52, 0) and \
-                    time <= datetime.datetime(2020, 9, 1, 0, 0, 0):  # 1250
-                f_calib = [0, 26, 10000, 20100, 30100, 40200, 50200]
-                sens_calib = [168.2, 168.2, 168.05, 169.85, 170.05,
-                              169.6, 170.45]
-                sens_interpolated = interp1d(f_calib, sens_calib)
+        # load calibration data as pandas dataframe
+        cal_by_assetID = pd.read_csv(filename, header=[0, 1])
 
-        elif node == '/LJ01D':  # Oregon Shelf Base Seafloor
-            if time >= datetime.datetime(2018, 6, 30, 2, 30, 0) and \
-                    time <= datetime.datetime(2019, 6, 19, 23, 31, 0):  # 1249
-                f_calib = [0, 26, 10000, 20100, 30100, 40200, 50200]
-                sens_calib = [168.5, 168.5, 167.6, 169.45, 171.85,
-                              172.65, 171.7]
-                sens_interpolated = interp1d(f_calib, sens_calib)
-            elif time >= datetime.datetime(2014, 9, 10, 15, 43, 0) and \
-                    time <= datetime.datetime(2015, 8, 1, 0, 0, 0) or \
-                    time >= datetime.datetime(2016, 7, 22, 22, 50, 0) and \
-                    time <= datetime.datetime(2017, 9, 9, 3, 30, 0):  # 1249
-                f_calib = [0, 26, 13500, 27100, 40600, 54100]
-                sens_calib = [170.53, 170.53, 175.1, 174.5, 174.6, 173.5]
-                sens_interpolated = interp1d(f_calib, sens_calib)
-            elif time >= datetime.datetime(2020, 9, 1, 0, 0, 0):  # 1248
-                f_calib = [0, 26, 10000, 20100, 30100, 40200, 50200]
-                sens_calib = [170.5, 170.5, 169.75, 172.85, 173.35,
-                              172.85, 172.25]
-                sens_interpolated = interp1d(f_calib, sens_calib)
-            elif time >= datetime.datetime(2015, 8, 2, 5, 47, 0) and \
-                    time <= datetime.datetime(2016, 7, 22, 22, 49, 59) or \
-                    time >= datetime.datetime(2017, 9, 10, 14, 30, 0) and \
-                    time <= datetime.datetime(2018, 6, 29, 2, 30, 0):  # 1411
-                f_calib = [0, 26, 10000, 20100, 30100, 40200, 50200]
-                sens_calib = [168.6, 168.6, 169.2, 170.9, 171.45,
-                              171.55, 174.2]
-                sens_interpolated = interp1d(f_calib, sens_calib)
-            elif time >= datetime.datetime(2019, 6, 23, 3, 36, 0) and \
-                    time <= datetime.datetime(2020, 9, 1, 0, 0, 0):  # 1411
-                f_calib = [0, 26, 10000, 20100, 30100, 40200, 50200]
-                sens_calib = [168.6, 168.6, 168.75, 169.6, 169.65,
-                              170.0, 170.2]
-                sens_interpolated = interp1d(f_calib, sens_calib)
+        f_calib = cal_by_assetID[assetID]['Freq (kHz)'].to_numpy() * 1000
+        sens_calib_0 = cal_by_assetID[assetID]['0 phase'].to_numpy()
+        sens_calib_90 = cal_by_assetID[assetID]['90 phase'].to_numpy()
+        sens_calib = 0.5 * (sens_calib_0 + sens_calib_90)
+        f = np.linspace(0, round(self.stats.sampling_rate / 2), N)
 
+        # Convert calibration to correct units
+        if round(self.stats.sampling_rate) == 200:
+            sens_calib = 20 * np.log10(sens_calib * 1e-6)
+        elif round(self.stats.sampling_rate) == 64000:
+            sens_calib = sens_calib + 128.9
         else:
-            output_array = 169.0 * np.ones(N)
-            return output_array
+            raise Exception('Invalid sampling rate')
 
-        return sens_interpolated(f)
+        sens_interpolated = interp1d(f_calib, sens_calib)
+
+        f_calib = sens_interpolated(f)
+        return f_calib
 
     def compute_spectrogram(self, win='hann', L=4096, avg_time=None,
                             overlap=0.5, verbose=True):
@@ -218,11 +178,10 @@ class HydrophoneData(Trace):
                     self.spectrogram = None
                     return None
                 else:
-                    calib_time = self.stats.starttime.datetime
-                    tmp = self.freq_dependent_sensitivity_correct(
-                        int(L / 2 + 1), self.stats.location, calib_time)
+                    sense_corr = -self.frequency_calibration(
+                        int(L / 2 + 1))
 
-                    Pxx = 10 * np.log10(Pxx * np.power(10, tmp / 10)) - 128.9
+                    Pxx = 10 * np.log10(Pxx * np.power(10, sense_corr / 10))
 
                     specgram.append(Pxx)
                     time.append(self.stats.starttime.datetime
@@ -243,11 +202,10 @@ class HydrophoneData(Trace):
                     self.spectrogram = None
                     return None
                 else:
-                    calib_time = self.stats.starttime.datetime
-                    tmp = self.freq_dependent_sensitivity_correct(
-                        int(L / 2 + 1), self.stats.location, calib_time)
+                    sense_corr = -self.frequency_calibration(
+                        int(L / 2 + 1))
 
-                    Pxx = 10 * np.log10(Pxx * np.power(10, tmp / 10)) - 128.9
+                    Pxx = 10 * np.log10(Pxx * np.power(10, sense_corr / 10))
                     specgram.append(Pxx)
                     time.append(self.stats.starttime.datetime
                                 + datetime.timedelta(seconds=n * avg_time))
@@ -267,11 +225,10 @@ class HydrophoneData(Trace):
                     self.spectrogram = None
                     return None
                 else:
-                    calib_time = self.stats.starttime.datetime
-                    tmp = self.freq_dependent_sensitivity_correct(
-                        int(L / 2 + 1), self.stats.location, calib_time)
+                    sense_corr = -self.frequency_calibration(
+                        int(L / 2 + 1))
 
-                    Pxx = 10 * np.log10(Pxx * np.power(10, tmp / 10)) - 128.9
+                    Pxx = 10 * np.log10(Pxx * np.power(10, sense_corr / 10))
                     specgram.append(Pxx)
                     time.append(self.stats.starttime.datetime
                                 + datetime.timedelta(seconds=(nbins - 1)
@@ -340,14 +297,16 @@ class HydrophoneData(Trace):
             temp_slice = self.slice(starttime=UTCDateTime(starttime),
                                     endtime=UTCDateTime(endtime))
             tmp_obj = HydrophoneData(data=temp_slice.data,
-                                     header=temp_slice.stats)
+                                     header=temp_slice.stats,
+                                     node=self.stats.location)
             ooi_hyd_data_list.append((tmp_obj, win, L, avg_time, overlap))
 
         starttime = self.stats.starttime + datetime.timedelta(
             seconds=(N - 1) * seconds_per_process)
         temp_slice = self.slice(starttime=UTCDateTime(starttime),
                                 endtime=UTCDateTime(self.stats.endtime))
-        tmp_obj = HydrophoneData(data=temp_slice.data, header=temp_slice.stats)
+        tmp_obj = HydrophoneData(data=temp_slice.data, header=temp_slice.stats,
+                                 node=self.stats.location)
         ooi_hyd_data_list.append((tmp_obj, win, L, avg_time, overlap))
 
         with mp.get_context("spawn").Pool(n_process) as p:
@@ -439,14 +398,13 @@ class HydrophoneData(Trace):
             self.psd = None
             return None
 
-        calib_time = self.stats.starttime.datetime
-        sense_corr = self.freq_dependent_sensitivity_correct(
-            int(nfft / 2 + 1), self.stats.location, calib_time)
+        sense_corr = -self.frequency_calibration(
+            int(nfft / 2 + 1))
+        print(sense_corr)
         if scale == 'log':
-            Pxx = 10 * np.log10(Pxx * np.power(10, sense_corr / 10)) - 128.9
+            Pxx = 10 * np.log10(Pxx * np.power(10, sense_corr / 10))
         elif scale == 'lin':
-            Pxx = Pxx * np.power(10, sense_corr / 10) * \
-                np.power(10, -128.9 / 10)
+            Pxx = Pxx * np.power(10, sense_corr / 10)
         else:
             raise Exception('scale has to be either "lin" or "log".')
 
@@ -523,7 +481,8 @@ class HydrophoneData(Trace):
                 temp_slice = self.slice(starttime=UTCDateTime(starttime),
                                         endtime=UTCDateTime(endtime))
                 tmp_obj = HydrophoneData(data=temp_slice.data,
-                                         header=temp_slice.stats)
+                                         header=temp_slice.stats,
+                                         node=self.stats.location)
                 ooi_hyd_data_list.append(
                     (tmp_obj, win, L, overlap, avg_method, interpolate, scale))
 
@@ -534,7 +493,8 @@ class HydrophoneData(Trace):
             temp_slice = self.slice(starttime=UTCDateTime(starttime),
                                     endtime=UTCDateTime(self.stats.endtime))
             tmp_obj = HydrophoneData(data=temp_slice.data,
-                                     header=temp_slice.stats)
+                                     header=temp_slice.stats,
+                                     node=self.stats.location)
             ooi_hyd_data_list.append(
                 (tmp_obj, win, L, overlap, avg_method, interpolate, scale))
         # use segmentation specified by split
@@ -544,7 +504,8 @@ class HydrophoneData(Trace):
                 temp_slice = self.slice(starttime=UTCDateTime(row[0]),
                                         endtime=UTCDateTime(row[1]))
                 tmp_obj = HydrophoneData(data=temp_slice.data,
-                                         header=temp_slice.stats)
+                                         header=temp_slice.stats,
+                                         node=self.stats.location)
                 ooi_hyd_data_list.append(
                     (tmp_obj, win, L, overlap, avg_method, interpolate, scale))
 
@@ -558,6 +519,200 @@ class HydrophoneData(Trace):
 
         return self.psd_list
 
+    def wav_write(self, filename, norm=False, new_sample_rate=None):
+        '''
+        method that stores HydrophoneData into .wav file
+
+        Parameters
+        ----------
+        filename : str
+            filename to store .wav file as
+        norm : bool
+            specifices whether data should be normalized to 1
+        new_sample_rate : float
+            specifices new sample rate of wav file to be saved. (Resampling is
+            done with scipy.signal.resample()). Default is None which keeps
+            original sample rate of data.
+        '''
+        if norm:
+            data = self.data / np.abs(np.max(self.data))
+        else:
+            data = self.data
+
+        if new_sample_rate is None:
+            sampling_rate = self.stats.sampling_rate
+        else:
+            if new_sample_rate > self.stats.sampling_rate:
+                upsamp_fac = new_sample_rate / self.stats.sampling_rate
+                new_npts = self.stats.npts * upsamp_fac
+                data = signal.resample(data, int(new_npts))
+                sampling_rate = new_sample_rate
+            elif new_sample_rate == self.stats.sampling_rate:
+                warnings.warn('New sample rate is same as original data. '
+                              'No resampling done.')
+                sampling_rate = self.stats.sampling_rate
+            elif new_sample_rate < self.stats.sampling_rate:
+                warnings.warn('New sample rate is lower than original sample'
+                              ' rate. Chebychev 1 anti-aliasing filter used')
+                if self.stats.sampling_rate % new_sample_rate != 0:
+                    raise Exception(
+                        'New Sample Rate is not factor of original sample rate'
+                    )
+                else:
+                    data = signal.decimate(
+                        data, int(self.stats.sampling_rate / new_sample_rate))
+                    sampling_rate = new_sample_rate
+
+        wavfile.write(filename, int(sampling_rate), data)
+
+    def get_asset_ID(self):
+        '''
+        get_asset_ID returns the hydrophone asset ID for a given data sample.
+        This data can be foun `here <https://raw.githubusercontent.com/
+        OOI-CabledArray/deployments/main/HYDBBA_deployments.csv'>`_ for
+        broadband hydrophones. Since Low frequency hydrophones remain
+        constant with location and time, if the hydrophone is low frequency,
+        the node ID is returned
+        '''
+        # Low frequency hydrophone
+        if round(self.stats.sampling_rate) == 200:
+            asset_ID = self.stats.location
+
+        elif round(self.stats.sampling_rate) == 64000:
+            url = 'https://raw.githubusercontent.com/OOI-CabledArray/' \
+                'deployments/main/HYDBBA_deployments.csv'
+            hyd_df = pd.read_csv(url)
+
+            # LJ01D'Oregon Shelf Base Seafloor
+            if self.stats.location == 'LJ01D':
+                ref = 'CE02SHBP-LJ01D-11-HYDBBA106'
+            # LJ01AOregon Slope Base Seafloor
+            if self.stats.location == 'LJ01A':
+                ref = 'RS01SLBS-LJ01A-09-HYDBBA102'
+            # Oregan Slope Base Shallow
+            if self.stats.location == 'PC01A':
+                ref = 'RS01SBPS-PC01A-08-HYDBBA103'
+            # Axial Base Shallow Profiler
+            if self.stats.location == 'PC03A':
+                ref = 'RS03AXPS-PC03A-08-HYDBBA303'
+            # Oregon Offshore Base Seafloor
+            if self.stats.location == 'LJ01C':
+                ref = 'CE04OSBP-LJ01C-11-HYDBBA105'
+            # Axial Base Seafloor
+            if self.stats.location == 'LJ03A':
+                ref = 'RS03AXBS-LJ03A-09-HYDBBA302'
+
+            hyd_df['referenceDesignator']
+
+            df_ref = hyd_df.loc[hyd_df['referenceDesignator'] == ref]
+
+            df_start = df_ref.loc[(df_ref['startTime'] < self.stats.starttime)
+                                  & (df_ref['endTime']
+                                  > self.stats.starttime)]
+            df_end = df_ref.loc[(df_ref['startTime'] < self.stats.endtime) &
+                                (df_ref['endTime'] > self.stats.endtime)]
+
+            if df_start.index.to_numpy() == df_end.index.to_numpy():
+                idx = df_start.index.to_numpy()
+                asset_ID = df_start['assetID'][int(idx)]
+            else:
+                raise Exception('Hydrophone Data involves multiple'
+                                'deployments. Feature to be added later')
+        else:
+            raise Exception('Invalid hydrophone sampling rate')
+
+        return asset_ID
+
+
+def node_id(node):
+    '''
+    mapping of name of hydrophone node to ID
+
+    Parameter
+    ---------
+    node : str
+        name or ID of the hydrophone node
+
+    Returns
+    -------
+    str
+        ID of hydrophone node
+    '''
+    # broadband hydrophones
+    if node == 'Oregon_Shelf_Base_Seafloor' or node == 'LJ01D':
+        return 'LJ01D'
+    if node == 'Oregon_Slope_Base_Seafloor' or node == 'LJ01A':
+        return 'LJ01A'
+    if node == 'Oregon_Slope_Base_Shallow' or node == 'PC01A':
+        return 'PC01A'
+    if node == 'Axial_Base_Shallow' or node == 'PC03A':
+        return 'PC03A'
+    if node == 'Oregon_Offshore_Base_Seafloor' or node == 'LJ01C':
+        return 'LJ01C'
+    if node == 'Axial_Base_Seafloor' or node == 'LJ03A':
+        return 'LJ03A'
+
+    # low frequency hydrophones
+    if node == 'Slope_Base' or node == 'HYSB1':
+        return 'HYSB1'
+    if node == 'Southern_Hydrate' or node == 'HYS14':
+        return 'HYS14'
+    if node == 'Axial_Base' or node == 'AXBA1':
+        return 'AXBA1'
+    if node == 'Central_Caldera' or node == 'AXCC1':
+        return 'AXCC1'
+    if node == 'Eastern_Caldera' or node == 'AXEC2':
+        return 'AXEC2'
+
+    else:
+        print('No node exists for name or ID ' + node)
+        return ''
+
+
+def node_name(node):
+    '''
+    mapping of ID of hydrophone node to name
+
+    Parameter
+    ---------
+    node : str
+        ID or name of the hydrophone node
+
+    Returns
+    -------
+    str
+        name of hydrophone node
+    '''
+    # broadband hydrophones
+    if node == 'Oregon_Shelf_Base_Seafloor' or node == 'LJ01D':
+        return 'Oregon_Shelf_Base_Seafloor'
+    if node == 'Oregon_Slope_Base_Seafloor' or node == 'LJ01A':
+        return 'Oregon_Slope_Base_Seafloor'
+    if node == 'Oregon_Slope_Base_Shallow' or node == 'PC01A':
+        return 'Oregon_Slope_Base_Shallow'
+    if node == 'Axial_Base_Shallow' or node == 'PC03A':
+        return 'Axial_Base_Shallow'
+    if node == 'Oregon_Offshore_Base_Seafloor' or node == 'LJ01C':
+        return 'Oregon_Offshore_Base_Seafloor'
+    if node == 'Axial_Base_Seafloor' or node == 'LJ03A':
+        return 'Axial_Base_Seafloor'
+
+    # low frequency hydrophones
+    if node == 'Slope_Base' or node == 'HYSB1':
+        return 'Slope_Base'
+    if node == 'Southern_Hydrate' or node == 'HYS14':
+        return 'Southern_Hydrate'
+    if node == 'Axial_Base' or node == 'AXBA1':
+        return 'Axial_Base'
+    if node == 'Central_Caldera' or node == 'AXCC1':
+        return 'Central_Caldera'
+    if node == 'Eastern_Caldera' or node == 'AXEC2':
+        return 'Eastern_Caldera'
+
+    else:
+        print('No node exists for ID or name ' + node)
+        return ''
+
 
 def _spectrogram_mp_helper(ooi_hyd_data_obj, win, L, avg_time, overlap):
     """
@@ -592,18 +747,6 @@ class Spectrogram:
         to be one entry in values. That is, if time has  length N and freq
         length M, values is a NxM array.
 
-    TODO:
-    Methods
-    -------
-    visualize(plot_spec=True, save_spec=False, filename='spectrogram.png',
-    title='spectrogram', xlabel='time', xlabel_rot=70, ylabel='frequency',
-    fmin=0, fmax=32, vmin=20, vmax=80, vdelta=1.0, vdelta_cbar=5,
-    figsize=(16,9), dpi=96)
-
-        Visualizes spectrogram using matplotlib.
-
-    save(filename='spectrogram.pickle')
-        Saves spectrogram in .pickle file.
     """
 
     def __init__(self, time, freq, values):
@@ -611,7 +754,6 @@ class Spectrogram:
         self.freq = freq
         self.values = values
 
-    # TODO: move visualization into separate module
     def visualize(self, plot_spec=True, save_spec=False,
                   filename='spectrogram.png', title='spectrogram',
                   xlabel='time', xlabel_rot=70, ylabel='frequency', fmin=0,
@@ -619,8 +761,11 @@ class Spectrogram:
                   vdelta_cbar=5, figsize=(16, 9), dpi=96, res_reduction_time=1,
                   res_reduction_freq=1, time_limits=None):
         """
-        !!!!! This function will be moved into a differnt module in the future.
-        The current documentation might not be accurate !!!!!
+        This function will be depreciated into a differnt module in the future.
+        The current documentation might not be accurate.
+
+        To plot spectrograms please see
+        :meth:`ooipy.hydrophone.basic.plot_spectrogram`
 
         Basic visualization of spectrogram based on matplotlib. The function
         offers two options: Plot spectrogram in Python (plot_spec = True) and
@@ -651,7 +796,9 @@ class Spectrogram:
             specifices xlimits on spectrogram. List contains two
             datetime.datetime objects
         """
-
+        import warnings
+        raise warnings.warn('will be depricated in future. Please see '
+                            'ooipy.tools.ooiplotlib.plot_spectrogram()')
         # set backend for plotting/saving:
         if not plot_spec:
             matplotlib.use('Agg')
@@ -725,6 +872,13 @@ class Spectrogram:
         with open(filename, 'wb') as outfile:
             pickle.dump(dct, outfile)
 
+    def plot(self, **kwargs):
+        '''
+        redirects to ooipy.ooiplotlib.plot_spectrogram()
+        please see :meth:`ooipy.hydrophone.basic.plot_spectrogram`
+        '''
+        ooipy.tools.ooiplotlib.plot_spectrogram(self, **kwargs)
+
 
 class Psd:
     """
@@ -782,7 +936,9 @@ class Psd:
         figsize (tuple(int)): size of figure
         dpi (int): dots per inch
         """
-
+        import warnings
+        raise warnings.warn('will be depricated in future. Please see '
+                            'ooipy.tools.ooiplotlib.plot_psd()')
         # set backend for plotting/saving:
         if not plot_psd:
             matplotlib.use('Agg')
@@ -854,3 +1010,10 @@ class Psd:
 
         with open(filename, 'w+') as outfile:
             json.dump(dct, outfile)
+
+    def plot(self, **kwargs):
+        '''
+        redirects to ooipy.ooiplotlib.plot_psd()
+        please see :meth:`ooipy.hydrophone.basic.plot_psd`
+        '''
+        ooipy.tools.ooiplotlib.plot_psd(self, **kwargs)
